
From: "Eric W. Biederman" <ebiederm@xmission.com>

In vmlinux.lds.h the code is carefull to define every section so vmlinux
properly reports the correct physical load address of code, as well as
it's virtual address.  

The new SECURITY_INIT definition fails to follow that convention and
and causes incorrect physical address to appear in the vmlinux if
there are any security initcalls.

This patch updates the SECURITY_INIT to follow the convention in the rest of
the file.

Signed-off-by: Eric Biederman <ebiederm@xmission.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/include/asm-generic/vmlinux.lds.h |    2 +-
 1 files changed, 1 insertion(+), 1 deletion(-)

diff -puN include/asm-generic/vmlinux.lds.h~vmlinux-fix-physical-addrs include/asm-generic/vmlinux.lds.h
--- 25/include/asm-generic/vmlinux.lds.h~vmlinux-fix-physical-addrs	2005-03-16 21:42:44.000000000 -0800
+++ 25-akpm/include/asm-generic/vmlinux.lds.h	2005-03-16 21:42:44.000000000 -0800
@@ -76,7 +76,7 @@
 	}
 
 #define SECURITY_INIT							\
-	.security_initcall.init : {					\
+	.security_initcall.init : AT(ADDR(.security_initcall.init) - LOAD_OFFSET) { \
 		VMLINUX_SYMBOL(__security_initcall_start) = .;		\
 		*(.security_initcall.init) 				\
 		VMLINUX_SYMBOL(__security_initcall_end) = .;		\
_
